package com.qianhe.system.controller;

import cn.hutool.core.util.IdUtil;
import cn.hutool.json.JSONUtil;
import com.github.wxpay.sdk.WXPayUtil;
import com.qianhe.common.core.domain.AjaxResult;
import com.qianhe.system.domain.WaterGoodsCart;
import com.qianhe.system.domain.WeChatPay;
import com.qianhe.system.service.impl.WeChatPayService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

import static com.qianhe.common.core.domain.AjaxResult.success;

/**
 * @author yc
 * @version 1.0
 * @className WeChatPayController
 * @date 2024/3/4 15:26
 * @description 支付下单
 */
@RestController
@RequestMapping("/weChatPay")
public class WeChatPayController {

    @Value("${wx.appId}")
    private String appId;

    @Value("${wx.mchId}")
    private String mchId;

    @Value("${wx.apiKey}")
    private String apiKey;

    @GetMapping("/pay")
    public AjaxResult orderPay(@RequestBody WaterGoodsCart goods){
        Map<String, Object> ResultMap = new HashMap<String, Object>();
        try {
            WeChatPay weChatPay = new WeChatPay();
            weChatPay.setAppid(appId);//公众号appid
            weChatPay.setMch_id(mchId);
            weChatPay.setApi_key(apiKey);//api密钥
            weChatPay.setNonce_str(WXPayUtil.generateNonceStr());// 32位随机字符串
            weChatPay.setBody(goods.getGoodsName()+goods.getGoodsTypeName()+goods.getGoodsId());// 商品描述
            weChatPay.setTotal_fee(String.valueOf(goods.getGoodsPrice())); //标价金额
            weChatPay.setOut_trade_no(IdUtil.simpleUUID());// 商户订单号 唯一
            weChatPay.setNotify_url("https://notify_url");//异步回调地址
            weChatPay.setTrade_type("JSAPI"); // 交易类型 JSAPI--JSAPI支付（或小程序支付）、NATIVE--Native支付、APP--app支付，MWEB--H5支付
            weChatPay.setAttach("附加数据NO.1");//附加数据，在查询API和支付通知中原样返回，该字段主要用于商户携带订单的自定义数据
            ResultMap = WeChatPayService.Unifiedorder(weChatPay);
            //log.info("返回结果：{}",JSONUtil.toJsonStr(ResultMap));
        } catch (Exception e) {
            ResultMap.put("code", 2);
            ResultMap.put("msg", "系统异常错误代码：" + e.getMessage());
            e.printStackTrace();
        }
        return success(JSONUtil.toJsonStr(ResultMap));
    }
}